[evolution-data-server] Bug 761506 - Rename SSL to TLS



commit 716662acabead5f9da0d364eea3bedf5d32aa43e
Author: Milan Crha <mcrha redhat com>
Date:   Tue Feb 9 10:27:06 2016 +0100

    Bug 761506 - Rename SSL to TLS

 calendar/backends/caldav/e-cal-backend-caldav.c |    2 +-
 camel/providers/imapx/camel-imapx-provider.c    |    2 +-
 camel/providers/nntp/camel-nntp-provider.c      |    2 +-
 camel/providers/pop3/camel-pop3-provider.c      |    2 +-
 camel/providers/smtp/camel-smtp-provider.c      |    2 +-
 libedataserver/e-source-webdav.c                |   13 ++++++-------
 libedataserver/e-source.c                       |    4 ++--
 libedataserver/e-source.h                       |    2 +-
 libedataserverui/e-trust-prompt.c               |   20 ++++++++++----------
 modules/trust-prompt/module-trust-prompt.c      |    2 +-
 modules/trust-prompt/trust-prompt-gtk.c         |    2 +-
 11 files changed, 26 insertions(+), 27 deletions(-)
---
diff --git a/calendar/backends/caldav/e-cal-backend-caldav.c b/calendar/backends/caldav/e-cal-backend-caldav.c
index 7b084e9..3284f94 100644
--- a/calendar/backends/caldav/e-cal-backend-caldav.c
+++ b/calendar/backends/caldav/e-cal-backend-caldav.c
@@ -696,7 +696,7 @@ status_code_to_result (SoupMessage *message,
                g_propagate_error (
                        perror,
                        e_data_cal_create_error_fmt ( OtherError,
-                       _("Failed to connect to a server using SSL: %s"),
+                       _("Failed to connect to a server using SSL/TLS: %s"),
                        message->reason_phrase && *message->reason_phrase ? message->reason_phrase :
                        (soup_status_get_phrase (message->status_code) ? soup_status_get_phrase 
(message->status_code) : _("Unknown error"))));
                if (is_opening && perror && *perror) {
diff --git a/camel/providers/imapx/camel-imapx-provider.c b/camel/providers/imapx/camel-imapx-provider.c
index 45c4172..bc9b94a 100644
--- a/camel/providers/imapx/camel-imapx-provider.c
+++ b/camel/providers/imapx/camel-imapx-provider.c
@@ -78,7 +78,7 @@ CamelProviderConfEntry imapx_conf_entries[] = {
 
 CamelProviderPortEntry imapx_port_entries[] = {
        { 143, N_("Default IMAP port"), FALSE },
-       { 993, N_("IMAP over SSL"), TRUE },
+       { 993, N_("IMAP over TLS"), TRUE },
        { 0, NULL, 0 }
 };
 
diff --git a/camel/providers/nntp/camel-nntp-provider.c b/camel/providers/nntp/camel-nntp-provider.c
index 86ee9c7..db28e25 100644
--- a/camel/providers/nntp/camel-nntp-provider.c
+++ b/camel/providers/nntp/camel-nntp-provider.c
@@ -52,7 +52,7 @@ static CamelProviderConfEntry nntp_conf_entries[] = {
 
 CamelProviderPortEntry nntp_port_entries[] = {
        { 119, N_("Default NNTP port"), FALSE },
-       { 563, N_("NNTP over SSL"), TRUE },
+       { 563, N_("NNTP over TLS"), TRUE },
        { 0, NULL, 0 }
 };
 
diff --git a/camel/providers/pop3/camel-pop3-provider.c b/camel/providers/pop3/camel-pop3-provider.c
index 4730a7f..2890703 100644
--- a/camel/providers/pop3/camel-pop3-provider.c
+++ b/camel/providers/pop3/camel-pop3-provider.c
@@ -50,7 +50,7 @@ static CamelProviderConfEntry pop3_conf_entries[] = {
 
 CamelProviderPortEntry pop3_port_entries[] = {
        { 110, N_("Default POP3 port"), FALSE },
-       { 995, N_("POP3 over SSL"), TRUE },
+       { 995, N_("POP3 over TLS"), TRUE },
        { 0, NULL, 0 }
 };
 
diff --git a/camel/providers/smtp/camel-smtp-provider.c b/camel/providers/smtp/camel-smtp-provider.c
index 43accb0..1ab3018 100644
--- a/camel/providers/smtp/camel-smtp-provider.c
+++ b/camel/providers/smtp/camel-smtp-provider.c
@@ -37,7 +37,7 @@ static gint smtp_url_equal (gconstpointer a, gconstpointer b);
 
 CamelProviderPortEntry smtp_port_entries[] = {
        { 25, N_("Default SMTP port"), FALSE },
-       { 465, N_("SMTP over SSL"), TRUE },
+       { 465, N_("SMTP over TLS"), TRUE },
        { 587, N_("Message submission port"), FALSE },
        { 0, NULL, 0 }
 };
diff --git a/libedataserver/e-source.c b/libedataserver/e-source.c
index c0ed3f1..ee81465 100644
--- a/libedataserver/e-source.c
+++ b/libedataserver/e-source.c
@@ -2326,8 +2326,8 @@ e_source_class_init (ESourceClass *class)
         * ESource::credentials-required:
         * @source: the #ESource that received the signal
         * @reason: an #ESourceCredentialsReason indicating why the credentials are requested
-        * @certificate_pem: PEM-encoded secure connection certificate for failed SSL checks
-        * @certificate_errors: what failed with the SSL certificate
+        * @certificate_pem: PEM-encoded secure connection certificate for failed SSL/TLS checks
+        * @certificate_errors: what failed with the SSL/TLS certificate
         * @error: a text description of the error, if any
         *
         * The ::credentials-required signal is emitted when the @source
diff --git a/libedataserver/e-source.h b/libedataserver/e-source.h
index e1d0112..66004fc 100644
--- a/libedataserver/e-source.h
+++ b/libedataserver/e-source.h
@@ -83,7 +83,7 @@
 /**
  * E_SOURCE_CREDENTIAL_SSL_TRUST:
  *
- * A name of the named parameter used for SSL trust in credentials,
+ * A name of the named parameter used for SSL/TLS trust in credentials,
  * used to authenticate users with e_source_invoke_authenticate_sync()
  * and e_source_invoke_authenticate(). The named parameter is optional.
  * Its value corresponds to current ESourceWebdav::ssl-trust property,
diff --git a/modules/trust-prompt/module-trust-prompt.c b/modules/trust-prompt/module-trust-prompt.c
index 6d3cc17..4005516 100644
--- a/modules/trust-prompt/module-trust-prompt.c
+++ b/modules/trust-prompt/module-trust-prompt.c
@@ -58,7 +58,7 @@ G_DEFINE_DYNAMIC_TYPE (
 /* ETrustPrompt::trust-prompt
  * The dialog expects these parameters:
  *    "host" - host from which the certificate is received
- *    "markup" - markup for the trust prompt, if not set, then "SSL certificate for '<b>host</b>' is not 
trusted. Do you wish to accept it?" is used
+ *    "markup" - markup for the trust prompt, if not set, then "SSL/TLS certificate for '<b>host</b>' is not 
trusted. Do you wish to accept it?" is used
  *    "certificate" - a base64-encoded DER certificate, for which ask on trust
  *    "certificate-errors" - a hexa-decimal integer (as string) corresponding to GTlsCertificateFlags
  *
diff --git a/modules/trust-prompt/trust-prompt-gtk.c b/modules/trust-prompt/trust-prompt-gtk.c
index 94a6b32..8907c88 100644
--- a/modules/trust-prompt/trust-prompt-gtk.c
+++ b/modules/trust-prompt/trust-prompt-gtk.c
@@ -156,7 +156,7 @@ trust_prompt_show (EUserPrompterServerExtension *extension,
                gchar *bhost;
 
                bhost = g_strconcat ("<b>", host, "</b>", NULL);
-               tmp = g_strdup_printf (_("SSL certificate for '%s' is not trusted. Do you wish to accept 
it?"), bhost);
+               tmp = g_strdup_printf (_("SSL/TLS certificate for '%s' is not trusted. Do you wish to accept 
it?"), bhost);
                g_free (bhost);
 
                markup = tmp;


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libedataserver/e-source-webdav.c b/libedataserver/e-source-webdav.c
index dfc87bb..5ad2135 100644
--- a/libedataserver/e-source-webdav.c
+++ b/libedataserver/e-source-webdav.c
@@ -574,9 +574,8 @@ e_source_webdav_class_init (ESourceWebdavClass *class)
                PROP_SSL_TRUST,
                g_param_spec_string (
                        "ssl-trust",
-                       "SSL Trust",
-                       "SSL certificate trust setting, "
-                       "for invalid server certificates",
+                       "SSL/TLS Trust",
+                       "SSL/TLS certificate trust setting, for invalid server certificates",
                        NULL,
                        G_PARAM_READWRITE |
                        G_PARAM_CONSTRUCT |
@@ -1050,7 +1049,7 @@ e_source_webdav_set_resource_query (ESourceWebdav *extension,
  * e_source_webdav_get_ssl_trust:
  * @extension: an #ESourceWebdav
  *
  * Returns an SSL certificate trust for the @extension.
  * The value encodes three parameters, divided by a pipe '|',
  * the first is users preference, can be one of "reject", "accept",
  * "temporary-reject" and "temporary-accept". The second is a host
@@ -1059,7 +1058,7 @@ e_source_webdav_set_resource_query (ESourceWebdav *extension,
  * it is supposed to be manipulated with e_source_webdav_update_ssl_trust()
  * and e_source_webdav_verify_ssl_trust().
  *
  * Returns: an SSL certificate trust for the @extension
  *
  * Since: 3.8
  **/
@@ -1107,7 +1106,7 @@ e_source_webdav_dup_ssl_trust (ESourceWebdav *extension)
  * @extension: an #ESourceWebdav
  * @ssl_trust: (allow-none): the ssl_trust to store, or %NULL to unset
  *
  * Sets the SSL certificate trust. See e_source_webdav_get_ssl_trust()
  * for more infomation about its content and how to use it.
  *
  * Since: 3.8
@@ -1336,7 +1335,7 @@ e_source_webdav_update_ssl_trust (ESourceWebdav *extension,
  * @cert: the invalid certificate of the connection over which @host is about
  *        to be sent
  *
  * Verifies SSL trust for the given @host and @cert, as previously stored in the @extension
  * with e_source_webdav_update_ssl_trust().
  **/
 ETrustPromptResponse
@@ -1050,7 +1049,7 @@ e_source_webdav_set_resource_query (ESourceWebdav *extension,
  * @extension: an #ESourceWebdav
  *
- * Returns an SSL certificate trust for the @extension.
+ * Returns an SSL/TLS certificate trust for the @extension.
  * The value encodes three parameters, divided by a pipe '|',
  * the first is users preference, can be one of "reject", "accept",
@@ -1059,7 +1058,7 @@ e_source_webdav_set_resource_query (ESourceWebdav *extension,
  * and e_source_webdav_verify_ssl_trust().
  *
- * Returns: an SSL certificate trust for the @extension
+ * Returns: an SSL/TLS certificate trust for the @extension
  *
  * Since: 3.8
@@ -1107,7 +1106,7 @@ e_source_webdav_dup_ssl_trust (ESourceWebdav *extension)
  * @ssl_trust: (allow-none): the ssl_trust to store, or %NULL to unset
  *
- * Sets the SSL certificate trust. See e_source_webdav_get_ssl_trust()
+ * Sets the SSL/TLS certificate trust. See e_source_webdav_get_ssl_trust()
  * for more infomation about its content and how to use it.
  *
@@ -1336,7 +1335,7 @@ e_source_webdav_update_ssl_trust (ESourceWebdav *extension,
  *        to be sent
  *
- * Verifies SSL trust for the given @host and @cert, as previously stored in the @extension
+ * Verifies SSL/TLS trust for the given @host and @cert, as previously stored in the @extension
  * with e_source_webdav_update_ssl_trust().
  **/
diff --git a/libedataserverui/e-trust-prompt.c b/libedataserverui/e-trust-prompt.c
index d582ddd..6f232ee 100644
--- a/libedataserverui/e-trust-prompt.c
+++ b/libedataserverui/e-trust-prompt.c
@@ -154,38 +154,38 @@ trust_prompt_show (GtkWindow *parent,
 
                if (g_str_equal (source_extension, E_SOURCE_EXTENSION_ADDRESS_BOOK)) {
                        tmp = g_strdup_printf (
-                               "An address book '%s' cannot connect, because an SSL certificate for '%s' is 
not trusted. Do you wish to accept it?",
+                               "An address book '%s' cannot connect, because an SSL/TLS certificate for '%s' 
is not trusted. Do you wish to accept it?",
                                bsource_display_name, bhost);
                } else if (g_str_equal (source_extension, E_SOURCE_EXTENSION_CALENDAR)) {
                        tmp = g_strdup_printf (
-                               "A calendar '%s' cannot connect, because an SSL certificate for '%s' is not 
trusted. Do you wish to accept it?",
+                               "A calendar '%s' cannot connect, because an SSL/TLS certificate for '%s' is 
not trusted. Do you wish to accept it?",
                                bsource_display_name, bhost);
                } else if (g_str_equal (source_extension, E_SOURCE_EXTENSION_MEMO_LIST)) {
                        tmp = g_strdup_printf (
-                               "A memo list '%s' cannot connect, because an SSL certificate for '%s' is not 
trusted. Do you wish to accept it?",
+                               "A memo list '%s' cannot connect, because an SSL/TLS certificate for '%s' is 
not trusted. Do you wish to accept it?",
                                bsource_display_name, bhost);
                } else if (g_str_equal (source_extension, E_SOURCE_EXTENSION_TASK_LIST)) {
                        tmp = g_strdup_printf (
-                               "A task list '%s' cannot connect, because an SSL certificate for '%s' is not 
trusted. Do you wish to accept it?",
+                               "A task list '%s' cannot connect, because an SSL/TLS certificate for '%s' is 
not trusted. Do you wish to accept it?",
                                bsource_display_name, bhost);
                } else if (g_str_equal (source_extension, E_SOURCE_EXTENSION_MAIL_ACCOUNT)) {
                        tmp = g_strdup_printf (
-                               "A mail account '%s' cannot connect, because an SSL certificate for '%s' is 
not trusted. Do you wish to accept it?",
+                               "A mail account '%s' cannot connect, because an SSL/TLS certificate for '%s' 
is not trusted. Do you wish to accept it?",
                                bsource_display_name, bhost);
                } else if (g_str_equal (source_extension, E_SOURCE_EXTENSION_MAIL_TRANSPORT)) {
                        tmp = g_strdup_printf (
-                               "A mail transport '%s' cannot connect, because an SSL certificate for '%s' is 
not trusted. Do you wish to accept it?",
+                               "A mail transport '%s' cannot connect, because an SSL/TLS certificate for 
'%s' is not trusted. Do you wish to accept it?",
                                bsource_display_name, bhost);
                } else {
                        tmp = g_strdup_printf (
-                               "An account '%s' cannot connect, because an SSL certificate for '%s' is not 
trusted. Do you wish to accept it?",
+                               "An account '%s' cannot connect, because an SSL/TLS certificate for '%s' is 
not trusted. Do you wish to accept it?",
                                bsource_display_name, bhost);
                }
 
                g_free (bsource_display_name);
        }
        if (!tmp)
-               tmp = g_strdup_printf (_("SSL certificate for '%s' is not trusted. Do you wish to accept 
it?"), bhost);
+               tmp = g_strdup_printf (_("SSL/TLS certificate for '%s' is not trusted. Do you wish to accept 
it?"), bhost);
        g_free (bhost);
 
        widget = gtk_label_new (NULL);
@@ -524,8 +524,8 @@ trust_prompt_get_host_from_url (const gchar *url)
  * @user_data: user data passed into @callback
  *
  * Similar to e_trust_prompt_run_modal(), except it also manages all the necessary things
  * around the @source<!-- -->'s SSL trust properties when it also contains %E_SOURCE_EXTENSION_WEBDAV,
  * thus the SSL trust on the WebDAV @source is properly updated based on the user's choice.
  * The call is finished with e_trust_prompt_run_for_source_finish(),
  * which also returns the user's choice. The finish happens in the @callback.
  * This is necessary, because the @source can be also saved.
@@ -524,8 +524,8 @@ trust_prompt_get_host_from_url (const gchar *url)
  *
  * Similar to e_trust_prompt_run_modal(), except it also manages all the necessary things
- * around the @source<!-- -->'s SSL trust properties when it also contains %E_SOURCE_EXTENSION_WEBDAV,
- * thus the SSL trust on the WebDAV @source is properly updated based on the user's choice.
+ * around the @source<!-- -->'s SSL/TLS trust properties when it also contains %E_SOURCE_EXTENSION_WEBDAV,
+ * thus the SSL/TLS trust on the WebDAV @source is properly updated based on the user's choice.
  * The call is finished with e_trust_prompt_run_for_source_finish(),
  * which also returns the user's choice. The finish happens in the @callback.